############# check required packages and install accordingly ###################
message('Checking packages.. Please wait!')
if (!require("presto")) remotes::install_github("immunogenomics/presto")
##################################################################################

########## Load Libraries ############################
message('Loading Libraries..')
suppressPackageStartupMessages(library(R.utils))
suppressPackageStartupMessages(library(dplyr))
suppressPackageStartupMessages(library(data.table))
suppressPackageStartupMessages(library(Seurat))
suppressPackageStartupMessages(library(rmarkdown))
suppressPackageStartupMessages(library(kableExtra))
suppressPackageStartupMessages(library(optparse))
suppressPackageStartupMessages(library(Matrix))
suppressPackageStartupMessages(library(presto))
suppressPackageStartupMessages(library(ggplot2))
suppressPackageStartupMessages(library(DT))
options(Seurat.object.assay.version = "v5")
######################################################


################# Set Arguments to be passed ############
message('Reaading Users arguments..')
option_list = list(
	make_option("--pathtoCogentDSreporter", type="character", default=NULL, help="Path to CogentDS reporter script", metavar="character"),
	make_option("--analyzeStats", type="character", default=NULL, help="Analyze Stats file generated by CogentAP", metavar="character"),
  make_option("--apSeuratObject", type="character", default=NULL, help="Seurat Object generated by CogentAP", metavar="character"),
  make_option("--clonotypeCounts", type="character", default=NULL, help="Immune Clonotype Counts", metavar="character"),
  make_option("--clonotypeSummary", type="character", default=NULL, help="Immune Clonotype Summary File", metavar="character"),
  make_option("--clonotypeMetadata", type="character", default=NULL, help="Immune Clonotype Metadata", metavar="character"),
  make_option("--fusiondir", type="character", default=NULL, help="Fusion output directory", metavar="character"),
  make_option("--outPath", type="character", default=NULL, help="Path to write Output files", metavar="character"),
  make_option("--matrixPath", type="character", default=NULL, help="Path to write Matrix files", metavar="character"),
  make_option("--outSeuratObject", type="character", default='CogentDS_analysis.rds', help="Output Seurat v5 Object", metavar="character"),
  make_option("--analyzeIsoformforReport", type="character", default=FALSE, help="is either TRUE / FALSE, by default: FALSE", metavar="character"),
  make_option("--outHTMLReport", type="character", default='CogentDS_preliminary-analysis_report.html', help="HTML report of analysis", metavar="character")

);  
opt_parser = OptionParser(option_list=option_list);
opt = parse_args(opt_parser);
#######################################################

########### Create path to required scripts ##########
if(!is.null(opt$pathtoCogentDSreporter)) {
	Get_ClonotypeData = paste0(opt$pathtoCogentDSreporter, "/bin/Get_ClonotypeData.R")
	Get_FusionData = paste0(opt$pathtoCogentDSreporter, "/bin/Get_FusionData.R")
	Generate_HTML_report = paste0(opt$pathtoCogentDSreporter, "/bin/Generate_HTML_report.R")
	if(!is.null(opt$outPath)) {
		dir.create(opt$outPath)
		temppath = paste0(opt$outPath, "/temp/")
		dir.create(temppath)
	} else {
		stop("--outPath is set to NULL!! value needed for writing files is specified directory")
	}
} else {
	stop("FATAL ERROR: Path to 'CogentDS_DataHandler_and_Reporter.R' is missing. Argument not supplied.. Found NULL", call.=FALSE)
}
########################################################


################# Check required Files ###############
message('Checking necessary files..')
if (is.null(opt$apSeuratObject)){
  print_help(opt_parser)
  stop("At least one argument must be supplied (apSeuratObject).n", call.=FALSE)
}
#####################################################

###################### Generate Gene Counts Seurat Object ##################
message('Reading Seurat Object generated by AP..')
if(!is.null(opt$apSeuratObject)) {
	seuratDSobject = readRDS(opt$apSeuratObject)
} else {
	seuratDSobject = NULL
	stop("Seurat object generated by AP is not found or set to NULL", call.=FALSE)
}
###########################################################################

################# Generate Clonotype Seurat Object ###################
message('Gathering Clonotype data..')
if(!is.null(opt$clonotypeCounts) && !is.null(opt$clonotypeSummary) && !is.null(opt$clonotypeMetadata) && !is.null(seuratDSobject)) {
	source(Get_ClonotypeData, local = TRUE)
} else {
	BCRl_mat = NULL
	BCRh_mat = NULL
	TCRa_mat = NULL
	TCRb_mat = NULL
	TCRdg_mat = NULL
	message("Clonotype metadata, counts or summary is missing or set to NULL")
}
######################################################################

################# Generate Fusion Matrices ###################
message('Gathering Gene Fusion data..')
if(!is.null(opt$fusiondir) && !is.null(seuratDSobject)) {
	source(Get_FusionData, local = TRUE)
} else {
	junction_reads = NULL
	span_frags = NULL
	message("Fusion counts or span fragments data is missing or set to NULL")
}
######################################################################

############# Generate Final Seurat v5 Object for DS ##################
message('Generating Final Object..')
if(!is.null(seuratDSobject)) {
	DefaultAssay(seuratDSobject) = "RNA"
	Idents(seuratDSobject) = "orig.ident"
	if((nrow(BCRl_mat) > 0) && (!is.null(BCRl_mat))) {
		BCRl_mat = BCRl_mat[,intersect(colnames(seuratDSobject[['RNA']]$counts), colnames(BCRl_mat))]
		seuratDSobject[['BCRl']] = CreateAssayObject(counts = BCRl_mat)
	}
	if((nrow(BCRh_mat) > 0) && (!is.null(BCRh_mat))) {
		BCRh_mat = BCRh_mat[,intersect(colnames(seuratDSobject[['RNA']]$counts), colnames(BCRh_mat))]
		seuratDSobject[['BCRh']] = CreateAssayObject(counts = BCRh_mat)
	}
	if((nrow(TCRa_mat) > 0) && (!is.null(TCRa_mat))) {
		TCRa_mat = TCRa_mat[,intersect(colnames(seuratDSobject[['RNA']]$counts), colnames(TCRa_mat))]
		seuratDSobject[['TCRa']] = CreateAssayObject(counts = TCRa_mat)
	}
	if((nrow(TCRb_mat) > 0) && (!is.null(TCRb_mat))) {
		TCRb_mat = TCRb_mat[,intersect(colnames(seuratDSobject[['RNA']]$counts), colnames(TCRb_mat))]
		seuratDSobject[['TCRb']] = CreateAssayObject(counts = TCRb_mat)
	}
	if((nrow(TCRdg_mat) > 0) && (!is.null(TCRdg_mat))) {
		TCRdg_mat = TCRdg_mat[,intersect(colnames(seuratDSobject[['RNA']]$counts), colnames(TCRdg_mat))]
		seuratDSobject[['TCRdg']] = CreateAssayObject(counts = TCRdg_mat)
	}

	if((nrow(junction_reads) > 0) && (!is.null(junction_reads))) {
		junction_reads = junction_reads[,intersect(colnames(seuratDSobject[['RNA']]$counts), colnames(junction_reads))]
		seuratDSobject[['junction_reads']] = CreateAssayObject(counts = junction_reads)
	}

	if((nrow(span_frags) > 0) && (!is.null(span_frags))) {
		span_frags = span_frags[,intersect(colnames(seuratDSobject[['RNA']]$counts), colnames(span_frags))]
		seuratDSobject[['span_frags']] = CreateAssayObject(counts = span_frags)
	}

	if(!is.null(opt$analyzeStats)) {
		stats = read.csv(opt$analyzeStats, header = TRUE, check.names = FALSE)
		if(length(unique(stats$Barcode)) > 1) {
			rownames(stats) = stats$Barcode
		} else {
			rownames(stats) = stats$Sample
		}
		DefaultAssay(seuratDSobject) = "RNA"
		stats = stats[colnames(seuratDSobject),]
		seuratDSobject = AddMetaData(seuratDSobject, metadata = stats)
	} else {
		message("analyze stats either set to NULL or not provided")
	}

	outfile = paste0(opt$outPath, "/", opt$outSeuratObject)
	saveRDS(seuratDSobject, file = outfile)

	if(length(Cells(seuratDSobject)) <= 5000) {
		message('Counts matrices in .csv format will be included in final output as num_cell <= 5000')
		gene_counts_intro_plus_exon = seuratDSobject[['RNA']]$counts
		out_counts_file = paste0(opt$matrixPath, "/", "geneCounts_exon_plus_intron.csv")
		write.csv(gene_counts_intro_plus_exon, out_counts_file, quote = F)
		if('Exon_RNA' %in% names(seuratDSobject)) {
			gene_counts_exonOnly = seuratDSobject[['Exon_RNA']]$counts
			out_counts_file = paste0(opt$matrixPath, "/", "geneCounts_exonOnly.csv")
			write.csv(gene_counts_exonOnly, out_counts_file, quote = F)
		}
		if('Transcript_RNA' %in% names(seuratDSobject)) {
			isoform_counts = seuratDSobject[['Transcript_RNA']]$counts
			out_counts_file = paste0(opt$matrixPath, "/", "isoformCounts.csv")
			write.csv(isoform_counts, out_counts_file, quote = F)
		}
		if('junction_reads' %in% names(seuratDSobject)) {
			junction_reads_counts = seuratDSobject[['junction_reads']]$counts
			out_counts_file = paste0(opt$matrixPath, "/", "fusion_junctionCounts.csv")
			write.csv(junction_reads_counts, out_counts_file, quote = F)
		}
		if('span_frags' %in% names(seuratDSobject)) {
			span_frags_counts = seuratDSobject[['span_frags']]$counts
			out_counts_file = paste0(opt$matrixPath, "/", "fusion_spanCounts.csv")
			write.csv(span_frags_counts, out_counts_file, quote = F)
		}
	} else {
		message('Counts matrices in .csv format will be excluded from final output as num_cell > 5000')
	}
} else {
	stop("Seurat object generated by AP is not found or set to NULL")
}
#########################################################################

################ Generate DS Report from Seurat Object ##################
message('Generating Report..')
if(!is.null(seuratDSobject))
{
	seuratDSobject_file = paste0(opt$outPath, "/", opt$outSeuratObject)
	source(Generate_HTML_report, local = TRUE)
	file_path = paste0(opt$outPath, "/", opt$outHTMLReport)
	if (file.exists(file_path)) {
		message('Seurat v5 object created and report generated')
	} else {
		message('Report generation failed')
	}
	unlink(temppath, recursive = TRUE)
} else {
	stop('Seurat v5 Object generation has failed! Please check inputs')
}
