library(dplyr)

immune_summary = read.csv(opt$clonotypeSummary, header = T, row.names = 1, check.names = F)
immune_meta = read.csv(opt$clonotypeMetadata, header = T, row.names = 1)
immune_matrix = read.csv(opt$clonotypeCounts, header = T, row.names = 1, check.names = F)

immune_meta_light = immune_meta %>% dplyr::filter(Light.Chain == "Y")
immune_meta_heavy = immune_meta %>% dplyr::filter(Heavy.Chain == "Y")

cols_immune_summary = colnames(immune_summary)

cols_immune_summary_imp = grep("_", cols_immune_summary, value = T)

not_needed_cols = 'Total_Reads'

cols_immune_summary_imp = cols_immune_summary_imp[! cols_immune_summary_imp %in% not_needed_cols]

cols_immune_summary_imp_TRA = grep('TRA', cols_immune_summary_imp, value = T)

cols_immune_summary_imp_TRB = grep('TRB', cols_immune_summary_imp, value = T)

cols_immune_summary_imp_TRD = grep('TRD', cols_immune_summary_imp, value = T)

cols_immune_summary_imp_TRG = grep('TRG', cols_immune_summary_imp, value = T)

cols_immune_summary_imp_TRDG = c(cols_immune_summary_imp_TRD, cols_immune_summary_imp_TRG)

TCR = c(cols_immune_summary_imp_TRA, cols_immune_summary_imp_TRB, cols_immune_summary_imp_TRDG)

cols_immune_summary_imp_B = cols_immune_summary_imp[! cols_immune_summary_imp %in% TCR]

TRA_values = c()
for(f in 1:length(cols_immune_summary_imp_TRA))
{
	immune_summary_temp = immune_summary %>% dplyr::select(cols_immune_summary_imp_TRA[f])
	values = unique(immune_summary_temp[[cols_immune_summary_imp_TRA[f]]])
	values = values[! values %in% c(".", "")]
	TRA_values = c(TRA_values, values)
}
TRA_values <- TRA_values[!is.na(TRA_values)]


TRB_values = c()
for(f in 1:length(cols_immune_summary_imp_TRB))
{
	immune_summary_temp = immune_summary %>% dplyr::select(cols_immune_summary_imp_TRB[f])
	values = unique(immune_summary_temp[[cols_immune_summary_imp_TRB[f]]])
	values = values[! values %in% c(".", "")]
	TRB_values = c(TRB_values, values)
}
TRB_values <- TRB_values[!is.na(TRB_values)]

TRDG_values = c()
for(f in 1:length(cols_immune_summary_imp_TRDG))
{
	immune_summary_temp = immune_summary %>% dplyr::select(cols_immune_summary_imp_TRDG[f])
	values = unique(immune_summary_temp[[cols_immune_summary_imp_TRDG[f]]])
	values = values[! values %in% c(".", "")]
	TRDG_values = c(TRDG_values, values)
}
TRDG_values <- TRDG_values[!is.na(TRDG_values)]

TRA_values = unique(TRA_values)
TRB_values = unique(TRB_values)
TRDG_values = unique(TRDG_values)
common_TRA_TRDG = intersect(TRA_values, TRDG_values)
common_TRB_TRDG = intersect(TRB_values, TRDG_values)

if(length(common_TRA_TRDG) > 0) {
	TRA_values = setdiff(TRA_values, common_TRA_TRDG)
	TRDG_values = setdiff(TRDG_values, common_TRA_TRDG)
	DG_bucket = c()
	TRA_bucket = c()
	for(f in 1:length(common_TRA_TRDG)) {
		check1 = grep('^TRD', common_TRA_TRDG[f], value = T)
		check2 = grep('^TRG', common_TRA_TRDG[f], value = T)
		check3 = grep('^TRA', common_TRA_TRDG[f], value = T)
		if(length(check1) > 0) {
			DG_bucket = c(DG_bucket, check1)
		}
		if(length(check2) > 0) {
			DG_bucket = c(DG_bucket, check2)
		}
		if(length(check3) > 0) {
			TRDG_values = setdiff(TRDG_values, check3)
			TRA_bucket = c(TRA_bucket, check3)
		}
		if((length(check1) == 0) && (length(check2) == 0)) {
			TRA_bucket = c(TRA_bucket, common_TRA_TRDG[f])
		}
	}
	TRA_values = c(TRA_values, TRA_bucket)
	TRDG_values = c(TRDG_values, DG_bucket)
	for(f in 1:length(TRDG_values)) {
		check1 = grep('^TRA', TRDG_values[f], value = T)
		if(length(check1) > 0) {
			TRDG_values = setdiff(TRDG_values, check1)
			TRA_values = c(TRA_values, check1)
		}
	}
	for(f in 1:length(TRA_values)) {
		check1 = grep('^TRD', TRA_values[f], value = T)
		check2 = grep('^TRG', TRA_values[f], value = T)
		if(length(check1) > 0) {
			TRA_values = setdiff(TRA_values, check1)
			TRDG_values = c(TRDG_values, check1)
		}
		if(length(check2) > 0) {
			TRA_values = setdiff(TRA_values, check2)
			TRDG_values = c(TRDG_values, check2)
		}
	}
	TRDG_values = unique(TRDG_values)
	TRA_values = unique(TRA_values)
}

if(length(common_TRB_TRDG) > 0) {
	TRB_values = setdiff(TRB_values, common_TRB_TRDG)
	TRDG_values = setdiff(TRDG_values, common_TRB_TRDG)
	DG_bucket = c()
	TRB_bucket = c()
	for(f in 1:length(common_TRB_TRDG)) {
		check1 = grep('^TRD', common_TRB_TRDG[f], value = T)
		check2 = grep('^TRG', common_TRB_TRDG[f], value = T)
		check3 = grep('^TRB', common_TRB_TRDG[f], value = T)
		if(length(check1) > 0) {
			DG_bucket = c(DG_bucket, check1)
		}
		if(length(check2) > 0) {
			DG_bucket = c(DG_bucket, check2)
		}
		if(length(check3) > 0) {
			TRDG_values = setdiff(TRDG_values, check3)
			TRB_bucket = c(TRB_bucket, check3)
		}
		if((length(check1) == 0) && (length(check2) == 0)) {
			TRB_bucket = c(TRB_bucket, common_TRB_TRDG[f])
		}
	}
	TRB_values = c(TRB_values, TRB_bucket)
	TRDG_values = c(TRDG_values, DG_bucket)
	for(f in 1:length(TRDG_values)) {
		check1 = grep('^TRB', TRDG_values[f], value = T)
		if(length(check1) > 0) {
			TRDG_values = setdiff(TRDG_values, check1)
			TRB_values = c(TRB_values, check1)
		}
	}
	for(f in 1:length(TRB_values)) {
		check1 = grep('^TRD', TRB_values[f], value = T)
		check2 = grep('^TRG', TRB_values[f], value = T)
		if(length(check1) > 0) {
			TRB_values = setdiff(TRB_values, check1)
			TRDG_values = c(TRDG_values, check1)
		}
		if(length(check2) > 0) {
			TRB_values = setdiff(TRB_values, check2)
			TRDG_values = c(TRDG_values, check2)
		}
	}
	TRDG_values = unique(TRDG_values)
	TRB_values = unique(TRB_values)
}


IG_values = c()
for(f in 1:length(cols_immune_summary_imp_B))
{
	immune_summary_temp = immune_summary %>% dplyr::select(cols_immune_summary_imp_B[f])
	values = unique(immune_summary_temp[[cols_immune_summary_imp_B[f]]])
	values = values[! values %in% c(".", "")]
	IG_values = c(IG_values, values)
}
IG_values <- IG_values[!is.na(IG_values)]

if(length(TRA_values) > 0) {
	TRA_values_split = strsplit(TRA_values, "*", fixed = T)
	TRA_values = c()
	for(f in 1:length(TRA_values_split))
	{
		values = TRA_values_split[[f]][1]
		TRA_values = c(TRA_values, values)
	}
	TRA_rownames = c()
	for(f in 1:length(TRA_values))
	{
		get_val = grep(paste0(as.character(TRA_values[f]), '.*\\$'), rownames(immune_matrix), value = T)
		if(!is.null(get_val) == TRUE)
		{
			TRA_rownames = c(TRA_rownames, get_val)
		}
	}
	TRA_rownames = unique(TRA_rownames)
} else {
	TRA_values = NULL
	TRA_rownames = NULL
}


if(length(TRB_values) > 0) {
	TRB_values_split = strsplit(TRB_values, "*", fixed = T)
	TRB_values = c()
	for(f in 1:length(TRB_values_split))
	{
		values = TRB_values_split[[f]][1]
		TRB_values = c(TRB_values, values)
	}

	TRB_rownames = c()
	for(f in 1:length(TRB_values))
	{
		get_val = grep(paste0(as.character(TRB_values[f]), '.*\\$'), rownames(immune_matrix), value = T)
		if(!is.null(get_val) == TRUE)
		{
			TRB_rownames = c(TRB_rownames, get_val)
		}
	}
	TRB_rownames = unique(TRB_rownames)
} else {
	TRB_values = NULL
	TRB_rownames = NULL
}

if(length(TRDG_values) > 0) {
	TRDG_values_split = strsplit(TRDG_values, "*", fixed = T)
	TRDG_values = c()
	for(f in 1:length(TRDG_values_split))
	{
		values = TRDG_values_split[[f]][1]
		TRDG_values = c(TRDG_values, values)
	}

	TRDG_rownames = c()
	for(f in 1:length(TRDG_values))
	{
		get_val = grep(paste0(as.character(TRDG_values[f]), '.*\\$'), rownames(immune_matrix), value = T)
		if(!is.null(get_val) == TRUE)
		{
			TRDG_rownames = c(TRDG_rownames, get_val)
		}
	}
	TRDG_rownames = unique(TRDG_rownames)
} else {
	TRDG_values = NULL
	TRDG_rownames = NULL
}

if(length(IG_values) > 0) {
	IG_values_split = strsplit(IG_values, "*", fixed = T)
	IG_values = c()
	for(f in 1:length(IG_values_split))
	{
		values = IG_values_split[[f]][1]
		IG_values = c(IG_values, values)
	}

	IG_rownames = c()
	for(f in 1:length(IG_values))
	{
		get_val = grep(paste0(as.character(IG_values[f]), '.*\\$'), rownames(immune_matrix), value = T)
		if(!is.null(get_val) == TRUE)
		{
			IG_rownames = c(IG_rownames, get_val)
		}
	}
	IG_rownames = unique(IG_rownames)
} else {
	IG_values = NULL
	IG_rownames = NULL
}


found = c(TRA_rownames, TRB_rownames, TRDG_rownames, IG_rownames)
notfound = rownames(immune_matrix)[! rownames(immune_matrix) %in% found]

if(length(notfound) > 0) {
	for (f in 1:length(notfound)) {
		temp_check1 = grep('TRA', notfound[f], value = T)
		temp_check2 = grep('TRB', notfound[f], value = T)
		temp_check3 = grep('TRD', notfound[f], value = T)
		temp_check4 = grep('TRG', notfound[f], value = T)
		if(length(temp_check1) > 0) {
			TRA_rownames = c(TRA_rownames, temp_check1)
			message('added notfound item to TRA')
		}
		if(length(temp_check2) > 0) {
			TRB_rownames = c(TRB_rownames, temp_check2)
			message('added notfound item to TRB')
		}
		if(length(temp_check3) > 0) {
			TRDG_rownames = c(TRDG_rownames, temp_check3)
			message('added notfound item to TRDG')
		}
		if(length(temp_check4) > 0) {
			TRDG_rownames = c(TRDG_rownames, temp_check4)
			message('added notfound item to TRDG')
		}
		if((length(temp_check1) == 0) && (length(temp_check2) == 0) && (length(temp_check3) == 0) && (length(temp_check4) == 0)) {
			IG_rownames = c(IG_rownames, notfound[f])
			message('added notfound item to IG')
		}
	}
}

common_TRA_TRDG_afterasignment = intersect(TRA_rownames, TRDG_rownames)
TRDG_rownames = setdiff(TRDG_rownames, common_TRA_TRDG_afterasignment)
common_TRB_TRDG_afterasignment = intersect(TRB_rownames, TRDG_rownames)
TRDG_rownames = setdiff(TRDG_rownames, common_TRB_TRDG_afterasignment)

found = c(TRA_rownames, TRB_rownames, TRDG_rownames, IG_rownames)
if(length(found) == length(rownames(immune_matrix))) {
	message("All clonotypes recovered from matrix")
}

IG_rownames_light = intersect(IG_rownames, rownames(immune_meta_light))
IG_rownames_heavy = intersect(IG_rownames, rownames(immune_meta_heavy))


if(length(IG_rownames_heavy) > 0) {
	BCRh_mat = immune_matrix[IG_rownames_heavy,]
} else {
	BCRh_mat = NULL
}

if(length(IG_rownames_light) > 0) {
	BCRl_mat = immune_matrix[IG_rownames_light,]
} else {
	BCRl_mat = NULL
}

if(length(TRB_rownames) > 0) {
	TCRb_mat = immune_matrix[TRB_rownames,]
} else {
	TCRb_mat = NULL
}

if(length(TRA_rownames) > 0) {
	TCRa_mat = immune_matrix[TRA_rownames,]
} else {
	TCRa_mat = NULL
}

if(length(TRDG_rownames) > 0) {
	TCRdg_mat = immune_matrix[TRDG_rownames,]
} else {
	TCRdg_mat = NULL
}
