process FILTER_READS {
    publishDir "${params.output_dir}", mode: 'copy'

    input:
        path(reads)
        path(demux_counts_file)
    
    output:
        path("filtered_reads/*.fastq.gz"), emit: filtered_reads
        path("filtered_reads/low-count-removed-barcodes.txt"), emit: removed_barcodes, optional: true
    
    script:
        """
        MIN_TOTAL_READS=${params.read_filter}
        declare -A SAMPLE_IDS
        declare -A SAMPLE_COUNTS

        mkdir -p filtered_reads

        while IFS=\$',\\r\\n' read -r BARCODE SAMPLE READ_PAIRS; do
            SAMPLE_IDS["\$BARCODE"]=\$SAMPLE
            SAMPLE_COUNTS["\$BARCODE"]=\$READ_PAIRS
        done < ${demux_counts_file}

        for BARCODE in "\${!SAMPLE_COUNTS[@]}"; do
            if [[ "\$BARCODE" != "Unselected" && "\$BARCODE" != "Short" && "\$BARCODE" != "Undetermined" ]]; then
                BARCODE_COUNTS=\${SAMPLE_COUNTS[\$BARCODE]}
                if [ \$BARCODE_COUNTS -lt \$MIN_TOTAL_READS ]; then
                    rm -f *_\${BARCODE}_*.fastq.gz 
                    echo -e "\$BARCODE\\t\${SAMPLE_IDS[\$BARCODE]}\\t\$BARCODE_COUNTS" >> "filtered_reads/low-count-removed-barcodes.txt"
                fi                
            fi
        done

        
        cp *.fastq.gz filtered_reads/. 

        """
        }
        