conda_env_path = "${params.cogent_root}" + '/config/env/picard.yaml'

process PICARD_DSALIGNMETRICS {
    conda conda_env_path
    publishDir "${params.output_dir}", mode: 'copy'

    input:
        tuple val(sample_id), path(bam), path(genome_fasta)
        

    output:
        tuple val(sample_id), path('picard_dsalignmetrics/*_alignment_metrics.txt'), emit: aln_metrics
        tuple val(sample_id), path('logs/picard_dsalignmetrics/*_aln_metrics.log'), emit: aln_metrics_log

    script:

        """ 
        mkdir -p picard_dsalignmetrics
        mkdir -p logs/picard_dsalignmetrics
        
        (picard -Xmx${task.memory.toMega()}M CollectAlignmentSummaryMetrics \\
        I=${bam} \\
        O=picard_dsalignmetrics/${sample_id}_ds_alignment_metrics.txt \\
        REFERENCE_SEQUENCE=${genome_fasta} \\
        ASSUME_SORTED=${params.assumesorted} \\
        EXPECTED_PAIR_ORIENTATIONS=${params.expectedpairorientation1} \\
        EXPECTED_PAIR_ORIENTATIONS=${params.expectedpairorientation2} \\
        TMP_DIR=${sample_id}_aln.tmp \\
        ) 2>&1 | tee logs/picard_dsalignmetrics/${sample_id}_ds_aln_metrics.log
        
        rm -rf ${sample_id}_aln.tmp

        """
}
