conda_env_path = "${params.cogent_root}" + '/config/env/picard.yaml'

process PICARD_DSMARKDUPLICATES {
    conda conda_env_path
    publishDir "${params.output_dir}", mode: 'copy'

    input:
        tuple val(sample_id), path(bam)

    output:
        tuple val(sample_id), path('picard_dsmarkduplicates/*_mkdup.bam'), emit: mkdup_bam
        tuple val(sample_id), path('picard_dsmarkduplicates/*_mkdup.bai'), emit: mkdup_bam_index
        tuple val(sample_id), path('picard_dsmarkduplicates/*_duplicate.txt'), emit: mkdup_metrics
        tuple val(sample_id), path('logs/picard_dsmarkduplicates/*_mkdup_metrics.log'), emit: mkdup_log

    script:

        """ 
        mkdir -p picard_dsmarkduplicates
        mkdir -p logs/picard_dsmarkduplicates
        
        (picard -Xmx${task.memory.toMega()}M MarkDuplicates \\
        I=${bam} \\
        O=picard_dsmarkduplicates/${sample_id}_ds_mkdup.bam \\
        ASSUME_SORTED=${params.assumesorted} \\
        METRICS_FILE=picard_dsmarkduplicates/${sample_id}_ds_duplicate.txt \\
        CREATE_INDEX=${params.createindex} \\
        MAX_FILE_HANDLES=1000 \\
        TMP_DIR=${sample_id}_mkdp_all.tmp \\
        ) 2>&1 | tee logs/picard_dsmarkduplicates/${sample_id}_ds_mkdup_metrics.log

        rm -rf ${sample_id}_mkdp_all.tmp

        """
}
