conda_env_path = "${params.cogent_root}" + '/config/env/picard.yaml'

process PICARD_MARKDUPLICATES {
    conda conda_env_path
    publishDir "${params.output_dir}", mode: 'copy'

    input:
        tuple val(sample_id), path(bam)

    output:
        tuple val(sample_id), path('picard_markduplicates/*_mkdup_all.bam'), optional:true, emit: mkdup_bam
        tuple val(sample_id), path('picard_markduplicates/*_mkdup_all.bai'), optional:true, emit: mkdup_bam_index
        tuple val(sample_id), path('picard_markduplicates/*_duplicate_all.txt'), emit: mkdup_metrics
        tuple val(sample_id), path('logs/picard_markduplicates/*_mkdup_metrics_all.log'), emit: mkdup_log

    script:

        """ 
        mkdir -p picard_markduplicates
        mkdir -p logs/picard_markduplicates
        
        (picard -Xmx${task.memory.toMega()}M MarkDuplicates \\
        I=${bam} \\
        O=picard_markduplicates/${sample_id}_mkdup_all.bam \\
        ASSUME_SORTED=${params.assumesorted} \\
        METRICS_FILE=picard_markduplicates/${sample_id}_duplicate_all.txt \\
        CREATE_INDEX=${params.createindex} \\
        MAX_FILE_HANDLES=1000 \\
        TMP_DIR=${sample_id}_mkdp_all.tmp \\
        ) 2>&1 | tee logs/picard_markduplicates/${sample_id}_mkdup_metrics_all.log

        rm -rf ${sample_id}_mkdp_all.tmp
        
        """
}
