nextflow.enable.dsl=2

conda_env_path = "${params.cogent_root}" + '/config/env/salmon.yaml'
if (params.type_of_experiment == "shasta_total_rna" && params.keep_intermediate ){
    publishdir_enabled = true
} else if (params.type_of_experiment == "shasta_total_rna" && !params.keep_intermediate ) {
    publishdir_enabled = false
} else {
    publishdir_enabled = true
}

process SALMON_QUANT {
    conda conda_env_path
    publishDir = [
        [
            path: { "${params.output_dir}" },
            mode: 'copy',
            pattern: "salmon_counts/*/*.sf",
            enabled: publishdir_enabled
        ],
        [
            path: { "${params.output_dir}" },
            mode: 'copy',
            pattern: "logs/salmon/*.log",
        ],
        [
            path: { "${params.output_dir}" },
            mode: 'copy',
            pattern: "logs/salmon/*.json",
        ]
    ]

    input:
        tuple val(sample_id), path(bam), path(transcript_fa)
        val(umi_only)

    output:
        path("salmon_counts/${sample_id}*_quant.sf"), emit: salmon_transcript_results
        path("salmon_counts/${sample_id}*_header.sf"), emit: salmon_transcript_header
        path("logs/salmon/${sample_id}*_salmon_quant.log"), emit: salmon_logs
        path("logs/salmon/${sample_id}*_meta_info.json"), emit:salmon_meta_info
        path("salmon_counts/${sample_id}/quant.sf"), emit: salmon_results_dir

    script:

        def strandedness =  'A'

        def output_dir = umi_only ? "${sample_id}_umionly" : "${sample_id}"
        def log_dir = umi_only ? "${sample_id}_salmon_umionly" : "${sample_id}_salmon"
        def min_frags = 1


        """
        mkdir -p salmon_counts
        mkdir -p logs/salmon

        salmon quant \\
            --threads ${task.cpus} \\
            --libType=${strandedness} \\
            --useVBOpt \\
            --writeUnmappedNames \\
            --minAssignedFrags ${min_frags} \\
            -a ${bam} \\
            -t ${transcript_fa} \\
            -o salmon_counts/${output_dir} \\
        
        cut -f1 salmon_counts/${output_dir}/quant.sf | \\
            sed '1s/^Name/TranscriptID/' > salmon_counts/${output_dir}_header.sf

        cut -f5 salmon_counts/${output_dir}/quant.sf | \\
            sed "1s/^NumReads/${output_dir}/" > salmon_counts/${output_dir}_quant.sf
        

        mv salmon_counts/${output_dir}/aux_info/meta_info.json \\
            logs/salmon/${output_dir}_meta_info.json
        
        mv salmon_counts/${output_dir}/logs/salmon_quant.log \\
            logs/salmon/${output_dir}_salmon_quant.log 

        """
}
