nextflow.enable.dsl=2

conda_env_path = "${params.cogent_root}" + '/config/env/sortmerna.yaml'
if (params.type_of_experiment == "shasta_total_rna" && params.keep_intermediate ){
    publishdir_enabled = true
} else if (params.type_of_experiment == "shasta_total_rna" && !params.keep_intermediate ) {
    publishdir_enabled = false
} else {
    publishdir_enabled = true
}

process SORTMERNA {
    conda conda_env_path
    publishDir = [
        [
            path: { "${params.output_dir}" },
            mode: 'copy',
            pattern: "ribodepletion/*.fastq.gz",
            enabled: publishdir_enabled
        ],
        [
            path: { "${params.output_dir}" },
            mode: 'copy',
            pattern: "logs/sortmerna/*.sortmerna.log",
        ],
        [
            path: { "${params.output_dir}" },
            mode: 'copy',
            pattern: "logs/sortmerna/*_sortmerna.stdout",
        ]
    ]

    input:
        tuple val(sample_id), path(reads), path(ribo_db)
        path(fastas)

    output:
        tuple val(sample_id), path("ribodepletion/*_non_rRNA_R*.fastq.gz"), emit: ribodepleted_fastqs
        path("logs/sortmerna/*.sortmerna.log"), emit: log
        path('logs/sortmerna/*_sortmerna.stdout'), emit: stdout

    script:

        def read1 = "--reads ${reads[0]}"
        def read2 = "--reads ${reads[1]} --paired_in --out2"

        def mv_r1 = "mv ribodepletion/non_rRNA_reads_fwd.f*q.gz ribodepletion/${sample_id}_non_rRNA_R1.fastq.gz"
        def mv_r2 = "mv ribodepletion/non_rRNA_reads_rev.f*q.gz ribodepletion/${sample_id}_non_rRNA_R2.fastq.gz"

        """
        mkdir ribodepletion
        mkdir -p logs/sortmerna

        (sortmerna \\
            ${'--ref '+fastas.join(' --ref ')} \\
            --idx-dir ${ribo_db} \\
            ${read1} \\
            ${read2} \\
            --threads ${task.cpus} \\
            --workdir ribodepletion/ \\
            --kvdb ribodepletion/kvdb \\
            --aligned ribodepletion/rRNA_reads \\
            --other ribodepletion/non_rRNA_reads \\
            --fastx \\
        ) 2>&1 | tee logs/sortmerna/${sample_id}_sortmerna.stdout

        ${mv_r1}
        ${mv_r2}
        mv ribodepletion/rRNA_reads.log logs/sortmerna/${sample_id}.sortmerna.log

        """
}
