nextflow.enable.dsl=2

conda_env_path = "${params.cogent_root}" + '/config/env/star_fusion.yaml'
if (params.type_of_experiment == "shasta_total_rna" && params.keep_intermediate ){
    publishdir_enabled = true
} else if (params.type_of_experiment == "shasta_total_rna" && !params.keep_intermediate ) {
    publishdir_enabled = false
} else {
    publishdir_enabled = true
}

process STAR_FUSION {
    conda conda_env_path
    publishDir = [
        [
            path: { "${params.output_dir}" },
            mode: 'copy',
            pattern: "star_fusion/*.tsv",
            enabled: publishdir_enabled
        ],
        [
            path: { "${params.output_dir}" },
            mode: 'copy',
            pattern: "logs/star_fusion/*.log",
        ]
    ]

    input:
        tuple val(sample_id), path(junction_file), path(fusion_index)

    output:
        path("star_fusion/${sample_id}_fusion_predictions.abridged.tsv"), emit: star_fusion_abridged_tsv
        path("star_fusion/${sample_id}_fusion_predictions.tsv"), emit: star_fusion_tsv
        path("logs/star_fusion/*.log"), emit: fusion_log

    script:
        """
        (STAR-Fusion \
            --genome_lib_dir "${fusion_index}" \
            -J "${junction_file}" \
            --output_dir "star_fusion/fusion_out_${sample_id}" \
            --CPU ${task.cpus} \
            --max_sensitivity \
        ) 2>&1 | tee ${sample_id}_fusion.log

        mv star_fusion/fusion_out_${sample_id}/star-fusion.fusion_predictions.abridged.tsv \
            star_fusion/${sample_id}_fusion_predictions.abridged.tsv

        mv star_fusion/fusion_out_${sample_id}/star-fusion.fusion_predictions.tsv \
            star_fusion/${sample_id}_fusion_predictions.tsv
        
        mkdir -p logs/star_fusion
        mv ${sample_id}_fusion.log logs/star_fusion/. 

        """
}
