conda_env_path = "${params.cogent_root}" + '/config/env/trimmomatic.yaml'
illuminaclip = "${params.cogent_root}" + '/config/TruSeq3-PE-2.fa'

process TRIMMOMATIC {
    conda conda_env_path
    publishDir "${params.output_dir}", mode: 'copy'

    input:
        tuple val(sample_id), path(reads)
    
    output:
        path("trimmed_fastqs/${sample_id}_trimmed_R*.fastq.gz"), emit: trimmed_reads
        path("trimmed_fastqs/${sample_id}_unpaired_R*.fastq.gz"), emit: unmapped_reads
        tuple val(sample_id), path("logs/trimmomatic/${sample_id}_trim_out.log"), emit: log
    
    script:
        def read1 = "${reads[0]}"
        def read2 = "${reads[1]}"
        """
        mkdir -p trimmed_fastqs
        mkdir -p logs/trimmomatic

        (trimmomatic PE \\
        $read1 \\
        $read2 \\
        trimmed_fastqs/${sample_id}_trimmed_R1.fastq.gz \\
        trimmed_fastqs/${sample_id}_unpaired_R1.fastq.gz \\
        trimmed_fastqs/${sample_id}_trimmed_R2.fastq.gz \\
        trimmed_fastqs/${sample_id}_unpaired_R2.fastq.gz \\
        ILLUMINACLIP:${illuminaclip}:${params.seedmismatches}:${params.palindromeclipthreshold}:${params.simpleclipthreshold}:${params.minadapterlength}:${params.keepbothreads} \\
        HEADCROP:${params.headcrop} \\
        MINLEN:${params.minlen} \\
        -threads ${task.cpus} \\
        ) 2>&1 | tee logs/trimmomatic/${sample_id}_trim_out.log
        """
}
